/*
 * Project name:
     Tilt click Board Example
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20150325:
       - initial release (DM);
 * Description:
     This is a simple demonstration of the Tilt click Board usage.
 * Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7
                      http://www.mikroe.com/easyft90x/

     Oscillator:      CPU at full system clock, 100.000MHz
     ext. modules:    Tilt click board
                      http://www.mikroe.com/click/tilt/
     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Place Tilt click board at the mikroBUS socket 1 on the EasyFT90x v7 board.
     - Put EasyTFT in its socket, turn on backlight using the SW5.8
 */

#include "resources.h"
#include "built_in.h"

// TFT module connections
char TFT_DataPort at GPIO_PORT_32_39;
sbit TFT_RST at GPIO_PIN42_bit;
sbit TFT_RS at GPIO_PIN40_bit;
sbit TFT_CS at GPIO_PIN41_bit;
sbit TFT_RD at GPIO_PIN46_bit;
sbit TFT_WR at GPIO_PIN47_bit;
sbit TFT_BLED at GPIO_PIN58_bit;
// End TFT module connections

sbit Tilt_V01 at GPIO_PIN56_bit;
sbit Tilt_V02 at GPIO_PIN3_bit;

void Auxiliary_Code() {
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  asm nop;
  TFT_DataPort = index;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = cmd;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = Hi(_data);
  asm nop; asm nop;
  Auxiliary_Code();
  asm nop;
  TFT_DataPort = Lo(_data);
  asm nop; asm nop;
  Auxiliary_Code();
}

void InitDisplay(){
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("Tilt Click", 125, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyFT90x v7", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Image_Jpeg(80, 55, arrows_default_jpg);             // Print arrows_default jpg picture on display
}

void main() {
  GPIO_Pin_Digital_Input(56);                             // Set GPIO pin 56 as digital input
  GPIO_Pin_Digital_Input(3);                              // Set GPIO pin 3 as digital input

  InitDisplay();                                          // Display initialization
  
  while(1){
    if ((Tilt_V02 == 1) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_left_jpg);            // Print arrows_left jpg picture on display
    }

    if ((Tilt_V02 == 0) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_right_jpg);           // Print arrows_right jpg picture on display
    }

    if ((Tilt_V02 == 1) & (Tilt_V01 == 1)){
      TFT_Image_Jpeg(80, 55, arrows_up_jpg);              // Print arrows_up jpg picture on display
    }

    if ((Tilt_V02 == 0) & (Tilt_V01 == 0)){
      TFT_Image_Jpeg(80, 55, arrows_down_jpg);            // Print arrows_down jpg picture on display
    }
  }
}